---
name: Bug report
about: Create a report to help us improve
title: ''
labels: requires triage
assignees: ''

---

**Describe the bug**
<!-- A clear and concise description of what the bug is. -->

**Expected behavior**
<!-- A clear and concise description of what you expected to happen. -->

**To Reproduce**
Please try to provide a [Minimal, Complete, and Verifiable](http://stackoverflow.com/help/mcve) example, with the migration script and/or the SQLAlchemy tables or models involved.
See also [Reporting Bugs](https://www.sqlalchemy.org/participate.html#bugs) on the website.

```py
# Insert code here
```

**Error**

```
# Copy error here. Please include the full stack trace.
```

**Versions.**
 - OS: 
 - Python:
 - Alembic:
 - SQLAlchemy:
 - Database:
 - DBAPI:

**Additional context**
<!-- Add any other context about the problem here. -->

**Have a nice day!**
